**Example 1: 信任文件**

本接口(TrustMalwares)将被识别木马文件设为信任。

Input: 

```
tccli yunjing TrustMalwares --cli-unfold-argument  \
    --Ids 123 456
```

Output: 
```
{
    "Response": {
        "RequestId": "354f4ac3-8546-4516-8c8a-69e3ab73aa8a"
    }
}
```

